@@ -1,7 +1,11 @@
-from django.core.cache.backends.base import CacheKeyWarning
-from health_check.backends.base import BaseHealthCheckBackend, ServiceUnavailable, ServiceReturnedUnexpectedResult
-from health_check.plugins import plugin_dir
 from django.core.cache import cache
+from django.core.cache.backends.base import CacheKeyWarning
+
+from health_check.backends.base import (
+    BaseHealthCheckBackend, ServiceReturnedUnexpectedResult, ServiceUnavailable
+)
+from health_check.plugins import plugin_dir
+
 
 class CacheBackend(BaseHealthCheckBackend):
 
@@ -19,4 +23,4 @@ class CacheBackend(BaseHealthCheckBackend):
         except Exception:
             raise ServiceUnavailable("Unknown exception")
 
-plugin_dir.register(CacheBackend)
\ No newline at end of file
+plugin_dir.register(CacheBackend)
