@@ -1,7 +1,15 @@
-from health_check.backends.base import BaseHealthCheckBackend, ServiceUnavailable, ServiceReturnedUnexpectedResult
-from health_check_db.models import TestModel
+import logging
+
 from django.db import DatabaseError, IntegrityError
+
+from health_check.backends.base import (
+    BaseHealthCheckBackend, ServiceReturnedUnexpectedResult, ServiceUnavailable
+)
 from health_check.plugins import plugin_dir
+from health_check_db.models import TestModel
+
+logger = logging.getLogger(__name__)
+
 
 class DjangoDatabaseBackend(BaseHealthCheckBackend):
 
@@ -13,8 +21,10 @@ class DjangoDatabaseBackend(BaseHealthCheckBackend):
             obj.delete()
             return True
         except IntegrityError:
+            logger.exception("Integrity Error")
             raise ServiceReturnedUnexpectedResult("Integrity Error")
         except DatabaseError:
+            logger.exception("Database Error")
             raise ServiceUnavailable("Database error")
 
 plugin_dir.register(DjangoDatabaseBackend)
